==> openledger-1.0.8.tar.gz: openledger-1.0.8/README.md <==
# Openledger Python Library

[![fern shield](https://img.shields.io/badge/%F0%9F%8C%BF-Built%20with%20Fern-brightgreen)](https://buildwithfern.com?utm_source=github&utm_medium=github&utm_campaign=readme&utm_source=https%3A%2F%2Fgithub.com%2Fopenledger%2Fopenledger-python-sdk)
[![pypi](https://img.shields.io/pypi/v/OpenLedger)](https://pypi.python.org/pypi/OpenLedger)

The Openledger Python library provides convenient access to the Openledger API from Python.

## Installation

```sh
pip install OpenLedger
```

## Reference

A full reference for this library is available [here](./reference.md).

## Usage

Instantiate and use the client with the following:

```python
from openledger import OpenLedgerClient

client = OpenLedgerClient(
    token="YOUR_TOKEN",
)
client.transactions.create_a_new_transaction(
    id_="id",
)
```

## Async Client

The SDK also exports an `async` client so that you can make non-blocking calls to our API.

```python
import asyncio

from openledger import AsyncOpenLedgerClient

client = AsyncOpenLedgerClient(
    token="YOUR_TOKEN",
)


async def main() -> None:
    await client.transactions.create_a_new_transaction(
        id_="id",
    )


asyncio.run(main())
```

## Exception Handling

When the API returns a non-success status code (4xx or 5xx response), a subclass of the following error
will be thrown.

```python
from openledger.core.api_error import ApiError

try:
    client.transactions.create_a_new_transaction(...)
except ApiError as e:
    print(e.status_code)
    print(e.body)
```

## Advanced

### Retries

The SDK is instrumented with automatic retries with exponential backoff. A request will be retried as long
as the request is deemed retriable and the number of retry attempts has not grown larger than the configured
retry limit (default: 2).

A request is deemed retriable when any of the following HTTP status codes is returned:

- [408](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/408) (Timeout)
- [429](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/429) (Too Many Requests)
- [5XX](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/500) (Internal Server Errors)

Use the `max_retries` request option to configure this behavior.

```python
client.transactions.create_a_new_transaction(..., request_options={
    "max_retries": 1
})
```

### Timeouts

The SDK defaults to a 60 second timeout. You can configure this with a timeout option at the client or request level.

```python

from openledger import OpenLedgerClient

client = OpenLedgerClient(
    ...,
    timeout=20.0,
)


# Override timeout for a specific method
client.transactions.create_a_new_transaction(..., request_options={
    "timeout_in_seconds": 1
})
```

### Custom Client

You can override the `httpx` client to customize it for your use-case. Some common use-cases include support for proxies
and transports.
```python
import httpx
from openledger import OpenLedgerClient

client = OpenLedgerClient(
    ...,
    httpx_client=httpx.Client(
        proxies="http://my.test.proxy.example.com",
        transport=httpx.HTTPTransport(local_address="0.0.0.0"),
    ),
)
```

## Contributing

While we value open-source contributions to this SDK, this library is generated programmatically.
Additions made directly to this library would have to be moved over to our generation code,
otherwise they would be overwritten upon the next generated release. Feel free to open a PR as
a proof of concept, but know that we will not be able to merge it as-is. We suggest opening
an issue first to discuss with us!

On the other hand, contributions to the README are always very welcome!

==> openledger-1.0.12.tar.gz: openledger-1.0.12/README.md <==
# Openledger Python Library

[![fern shield](https://img.shields.io/badge/%F0%9F%8C%BF-Built%20with%20Fern-brightgreen)](https://buildwithfern.com?utm_source=github&utm_medium=github&utm_campaign=readme&utm_source=https%3A%2F%2Fgithub.com%2Fopenledger%2Fopenledger-python-sdk)
[![pypi](https://img.shields.io/pypi/v/OpenLedger)](https://pypi.python.org/pypi/OpenLedger)

The Openledger Python library provides convenient access to the Openledger API from Python.

## Installation

```sh
pip install OpenLedger
```

## Reference

A full reference for this library is available [here](./reference.md).

## Usage

Instantiate and use the client with the following:

```python
from openledger import OpenLedgerClient
client = OpenLedgerClient(token="YOUR_TOKEN", )
client.categories.create_a_new_category(entity_id='entityId', name='name', type="ASSET", )
```

## Async Client

The SDK also exports an `async` client so that you can make non-blocking calls to our API.

```python
from openledger import AsyncOpenLedgerClient
import asyncio
client = AsyncOpenLedgerClient(token="YOUR_TOKEN", )
async def main() -> None:
    await client.categories.create_a_new_category(entity_id='entityId', name='name', type="ASSET", )
asyncio.run(main())```

## Exception Handling

When the API returns a non-success status code (4xx or 5xx response), a subclass of the following error
will be thrown.

```python
from openledger.core.api_error import ApiError
try:
    client.categories.create_a_new_category(...)
except ApiError as e:
    print(e.status_code)
    print(e.body)
```

## Advanced

### Access Raw Response Data

The SDK provides access to raw response data, including headers, through the `.with_raw_response` property.
The `.with_raw_response` property returns a "raw" client that can be used to access the `.headers` and `.data` attributes.

```python
from openledger import OpenLedgerClient
client = OpenLedgerClient(..., )
response = client.categories.with_raw_response.create_a_new_category(...)
print(response.headers)  # access the response headers
print(response.data)  # access the underlying object
```

### Retries

The SDK is instrumented with automatic retries with exponential backoff. A request will be retried as long
as the request is deemed retryable and the number of retry attempts has not grown larger than the configured
retry limit (default: 2).

A request is deemed retryable when any of the following HTTP status codes is returned:

- [408](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/408) (Timeout)
- [429](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/429) (Too Many Requests)
- [5XX](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/500) (Internal Server Errors)

Use the `max_retries` request option to configure this behavior.

```python
client.categories.create_a_new_category(..., request_options={
    "max_retries": 1
})
```

### Timeouts

The SDK defaults to a 60 second timeout. You can configure this with a timeout option at the client or request level.

```python

from openledger import OpenLedgerClient
client = OpenLedgerClient(..., timeout=20.0, )

# Override timeout for a specific method
client.categories.create_a_new_category(..., request_options={
    "timeout_in_seconds": 1
})
```

### Custom Client

You can override the `httpx` client to customize it for your use-case. Some common use-cases include support for proxies
and transports.

```python
from openledger import OpenLedgerClient
import httpx
client = OpenLedgerClient(..., httpx_client=httpx.Client(proxies="http://my.test.proxy.example.com", transport=httpx.HTTPTransport(local_address="0.0.0.0"), ))```

## Contributing

While we value open-source contributions to this SDK, this library is generated programmatically.
Additions made directly to this library would have to be moved over to our generation code,
otherwise they would be overwritten upon the next generated release. Feel free to open a PR as
a proof of concept, but know that we will not be able to merge it as-is. We suggest opening
an issue first to discuss with us!

On the other hand, contributions to the README are always very welcome!
